#!/usr/bin/env python3
#
# Run a search against file-listing and print the results in the CLI
#
# 

import os
import requests
import sys
import shutil

SEARCH_URL = os.getenv("SEARCH_URL", False)
RESULT_LIMIT = int(os.getenv("RESULT_LIMIT", 0))

# Optional - setting these will add dorks to the search
SEARCH_PREFIX = os.getenv("SEARCH_PREFIX", False)
SEARCH_DOMAIN = os.getenv("SEARCH_DOMAIN", False)

def doSearch(query, url):
    ''' Make a call to file-location
    '''
    query_obj = {
        "term" : query,
        "type": "DOC"
        }
    
    if RESULT_LIMIT:
        query_obj["limit"] = RESULT_LIMIT

    if SEARCH_PREFIX:
        query_obj["term"] += f" prefix:{SEARCH_PREFIX}"

    if SEARCH_DOMAIN:
        query_obj["term"] += f" domain:{SEARCH_DOMAIN}"

    r = requests.post(url, json=query_obj)

    return r.json()


def printResults(j):
    ''' Iterate through results and print them
    
    '''
    end_esc='\033[0m'

    seen=[]
    colwidth = shutil.get_terminal_size().columns

    if colwidth > 90:
        colwidth = 90

    for r in j['results']:
        url = r['key']
        size = round(int(r['bytes']) / 1024 / 1024, 3)

        if url in seen:
            continue


        if len(r['title']) > 0:
            print(f'\33[1m\033[94m{r["title"]}{end_esc}')
            
        print(f'\33[3m\033[92m{url}{end_esc}')
        print('')
        print(f'{size} MiB\n')
        print(f'\33[90mIndexed At: {r["valid-at"]} {end_esc}')
        print(f'\33[90mLast Mod: {r["last-mod"]} {end_esc}')
        print('-' * colwidth)

        seen.append(url)
    

res = doSearch(' '.join(sys.argv[1:]), SEARCH_URL)
printResults(res)
