#!/usr/bin/env python3
#
# Validate URLs from the index and remove anything that's no longer valid
#
'''
Copyright (c) 2023 B Tasker

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

    Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.

    Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.

    Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
'''

import os
import random
import sys

sys.path.append(os.path.join(os.path.dirname(__file__), '../lib'))
sys.path.append(os.path.join(os.path.dirname(__file__), '../crawler/app'))

import crawler
import config
import storage



def selectURLS(num):
    ''' Pick a random selection of URLs out of the index
    '''
    
    result = []
    for s in random.sample(storage.INDEXES["ALL"], num):
        result.append(s['u'])
        
    return result
        

def validateURL(url):
    ''' Trigger a crawl to verify that the URL is still valid
    '''
    return crawler.crawlPage(url, override = False, ele = False)
    

if __name__ == "__main__":
    DB_PATH = config.getDBPath()
    storage.DB_PATH = DB_PATH
    
    # We want the ALL index enabled
    storage.INDEX_ALL = True
    
    # Load the index
    storage.loadIndex()
    
    urls = selectURLS(config.getRevalidateCount())
    for url in urls:
        if not validateURL(url):
            print(f"No longer valid: {url}")
    
    storage.indexStorage()
